@@ -1,6 +1,6 @@
 #include "wrsink.h"
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
+#include <mbarcode-qt/pluginaction.h>
 
 #include <QtCore>
 #include <QProcess>
@@ -10,13 +10,14 @@
 #include "providerwindow.h"
 #include "wrplugin.h"
 
-WrSink::WrSink(const PluginInterface *interface) : SinkPlugin(interface) {
+WrSink::WrSink(const PluginInterface *interface) : PluginAction(interface) {
     ready = false;
+    image = QImage(":/images/globe.png");
+    image = image.scaledToHeight(48, Qt::SmoothTransformation);
 }
 
-QString WrSink::getText()
-{
-    return "Search the Web";
+QString WrSink::getInformativeText() {
+    return "Search the web for " + barcodeText.left(20) + "...";
 }
 
 void WrSink::clickAction(QWidget *parentWindow) {
@@ -31,3 +32,7 @@ bool WrSink::isReady() {
 void WrSink::setPlugin(WrPlugin *plugin) {
     this->plugin = plugin;
 }
+
+QImage WrSink::getImage() {
+    return image;
+}
